@@ -10,14 +10,14 @@
 #include <tqwhatsthis.h>
 
 #include <knuminput.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kiconloader.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbarbutton.h>
 #include <klineedit.h>
 #include <kinputdialog.h>
 //#include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include <math.h>
 
@@ -188,7 +188,7 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
              );
     normalBottomBox->addSpacing( 18 );
 
-    pProfileSave = new KToolBarButton( "filesave", 1003, normalOptions, "pProfileSave" );
+    pProfileSave = new TDEToolBarButton( "document-save", 1003, normalOptions, "pProfileSave" );
     TQToolTip::add( pProfileSave, i18n("Save current options as a profile") );
     normalBottomBox->addWidget( pProfileSave, 0, TQt::AlignVCenter );
     connect( pProfileSave, TQT_SIGNAL(clicked()),
@@ -675,7 +675,7 @@ void OptionsDetailed::qualityChanged()
 //                         t_int = ( (100 - item->fileListItem->options.encodingOptions.iQuality) * (int)( plugin->enc.lossy.quality.range_min - plugin->enc.lossy.quality.range_max ) / 100) + (int)plugin->enc.lossy.quality.range_max;
                         quality.replace( "%q", TQString::number( ( (100 - qualityLevel) * (int)( plugin->enc.lossy.quality.range_min - plugin->enc.lossy.quality.range_max ) / 100) + (int)plugin->enc.lossy.quality.range_max ) );
                 }
-                if( plugin->enc.bin == "oggenc" ) quality.replace(TQChar('.'),KGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
+                if( plugin->enc.bin == "oggenc" ) quality.replace(TQChar('.'),TDEGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
                 else if( plugin->enc.lossy.quality.separator != '.' ) {
                     quality.replace( TQChar('.'), plugin->enc.lossy.quality.separator );
                 }
